@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# Copyright [1999-2016] EMBL-European Bioinformatics Institute
+# Copyright [2015-2017] EMBL-European Bioinformatics Institute
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +20,7 @@ use Cwd;
 use File::Path qw(make_path);
 use Getopt::Long;
 
-my $htslib_version = "1.3.1";
+my $htslib_version = "1.5";
 
 my $help = "INSTALL.pl [-h|--help] [--prefix=filepath] [--static] [~/prefix/path]\n";
 $help .= "--help (-h)  - this help message\n";
@@ -38,6 +38,7 @@ my $prefix_path;
 $prefix_path = $opts->{'prefix'} if(exists($opts->{'prefix'}) && defined($opts->{'prefix'}));
 $htslib_version = $opts->{'htslib_version'} if($opts->{'htslib_version'}) ;
 
+my ($version_major,$version_minor,$version_revision) = split /\./, $htslib_version ;
 
 
 # STEP 0: various dependencies
@@ -64,13 +65,35 @@ On Debian/Ubuntu systems you can do this with the command:
   apt-get install build-essential
 END
 
+# The following libraries are version number dependant for HTSlib
+if( $version_major >= 2 || ($version_major==1 && $version_minor>=5) )
+{
+-e '/usr/include/lzma.h' or die <<END;
+lzma.h library header not found in /usr/include. Please install it and try again.
+On Debian/Ubuntu systems you can do this with the command:
+
+  apt-get install liblzma-dev
+END
+
+-e '/usr/include/bzlib.h' or die <<END;
+zlib.h library header not found in /usr/include. Please install it and try again.
+On Debian/Ubuntu systems you can do this with the command:
+
+  apt-get install libbz2-dev
+END
+}
+else
+{
 -e '/usr/include/zlib.h' or die <<END;
 zlib.h library header not found in /usr/include. Please install it and try again.
 On Debian/Ubuntu systems you can do this with the command:
 
   apt-get install zlib1g-dev
 END
+
     ;
+}
+
 
 eval "require Bio::SeqFeature::Lite" or die <<END;
 BioPerl does not seem to be installed. Please install it and try again.
@@ -94,7 +117,7 @@ info("Checking out HTSlib v".$htslib_version);
 chdir $install_dir;
 my $htslib_archive = $htslib_version.".zip" ;
 my $htslib_archive_url = "https://github.com/samtools/htslib/archive/".$htslib_version.".zip" ;
-system "wget ".$htslib_archive_url  ;
+system "wget -O " . $htslib_archive . " " .$htslib_archive_url  ;
 if ( $? == -1 )
 {
   die "HTSlib fetch command failed: $!\n";
@@ -110,12 +133,12 @@ info("Fetching latest version of Bio-DB-HTS from GitHub");
 chdir $install_dir;
 my $biodbhts_archive = "master.zip" ;
 my $biodbhts_archive_url = "https://github.com/Ensembl/Bio-DB-HTS/archive/master.zip" ;
-system "wget ".$biodbhts_archive_url  ;
+system "wget -O " . $biodbhts_archive . " " .$biodbhts_archive_url  ;
 if ( $? == -1 )
 {
   die "Bio-DB-HTS fetch command failed: $!\n";
 }
--f './'.$htslib_archive or die "Could not fetch Bio::DB::HTS archive ".$biodbhts_archive_url ;
+-f './'.$biodbhts_archive or die "Could not fetch Bio::DB::HTS archive ".$biodbhts_archive_url ;
 system "unzip ".$biodbhts_archive ;
 system "mv Bio-DB-HTS-master Bio-DB-HTS" ;
 -d './Bio-DB-HTS' or die "Unzip seems to have failed. Could not find $install_dir/Bio-DB-HTS directory";
